@@ -3,5 +3,5 @@
 #puts Net::SSH::Version::CURRENT
 require 'common'
 Dir.chdir(File.dirname(__FILE__)) do
-  Dir['**/test_*.rb'].each { |file| require(file) }
+  Dir['**/test_*.rb'].each { |file| require(file) unless file == File.basename(__FILE__) }
 end
\ No newline at end of file
